﻿using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI;
using Windows.UI.Core;
using Windows.UI.Input.Inking;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 잉크 프리젠터
        /// </summary>
        private InkPresenter inkPresenter;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "InkCanvas 엘리먼트 사용하기";

            #endregion

            this.inkPresenter = this.inkCanvas.InkPresenter;

            this.inkPresenter.InputDeviceTypes = CoreInputDeviceTypes.Mouse | CoreInputDeviceTypes.Pen | CoreInputDeviceTypes.Touch;

            UpdatePen();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 펜 색상 콤보 박스 선택 변경시 처리하기 - penColorComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 펜 색상 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void penColorComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            UpdatePen();
        }

        #endregion
        #region 스트로크 크기 슬라이더 값 변경시 처리하기 - strokeSizeSlider_ValueChanged(sender, e)

        /// <summary>
        /// 스트로크 크기 슬라이더 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void strokeSizeSlider_ValueChanged(object sender, RangeBaseValueChangedEventArgs e)
        {
            UpdatePen();
        }

        #endregion
        #region 하이라이트 그리기 체크 박스 체크시 처리하기 - drawAsHighlighterCheckBox_Checked(sender, e)

        /// <summary>
        /// 하이라이트 그리기 체크 박스 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void drawAsHighlighterCheckBox_Checked(object sender, RoutedEventArgs e)
        {
            UpdatePen();
        }

        #endregion
        #region 펜 팁 라디오 버튼 체크시 처리하기 - penTipRadioButton_Checked(sender, outedEventArgs e)

        /// <summary>
        /// 펜 팁 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void penTipRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            UpdatePen();
        }

        #endregion
        #region 모두 지우기 버튼 클릭시 처리하기 - clearAllButton_Click(sender, e)

        /// <summary>
        /// 모두 지우기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void clearAllButton_Click(object sender, RoutedEventArgs e)
        {
            this.inkPresenter.StrokeContainer.Clear();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 펜 업데이트하기 - UpdatePen()

        /// <summary>
        /// 펜 업데이트하기
        /// </summary>
        private void UpdatePen()
        {
            if(this.inkPresenter != null)
            {
                InkDrawingAttributes defaultAttributes = this.inkPresenter.CopyDefaultDrawingAttributes();

                switch(this.penColorComboBox.SelectedValue.ToString())
                {
                    case "검정색" : defaultAttributes.Color = Colors.Black; break;
                    case "빨간색" : defaultAttributes.Color = Colors.Red;   break;
                    case "파란색" : defaultAttributes.Color = Colors.Blue;  break;
                    case "녹색"   : defaultAttributes.Color = Colors.Green; break;
                }

                defaultAttributes.Size              = new Size(this.strokeSizeSlider.Value, this.strokeSizeSlider.Value);
                defaultAttributes.DrawAsHighlighter = this.drawAsHighlighterCheckBox.IsChecked.Value;
                defaultAttributes.PenTip            = (bool)this.circlePenTipRadioButton.IsChecked ? PenTipShape.Circle : PenTipShape.Rectangle;

                this.inkPresenter.UpdateDefaultDrawingAttributes(defaultAttributes);
            }
        }

        #endregion
    }
}